WebLogo 3 - Create
Author: Gavin E. Crooks

# WebLogo 3 : Create | · about · create · examples · manual · $version
Sequence data |
| (or paste sequence data below)
${sequences}
| Download
${error_message}
Output format |
Logo size |
Stacks per line |
Sequence type |
Ignore lower case |
Units |
First position number |
Logo range | -
Composition | or % CG
Scale stack widths |
Error bars |
Title |
Figure label |
X-axis | Label:
Y-axis | Label:
Y-axis scale: |
Y-axis tic spacing: |
Sequence end labels |
Version fineprint |
Color scheme |
Symbols | Color